Welcome to twiss's documentation!
===================================

Coupled twiss parameters (Wolski twiss matrices) computation for arbitrary even dimension.

.. toctree::
   :caption: Examples:
   :maxdepth: 1

   examples/twiss.ipynb

.. toctree::
   :caption: API:
   :maxdepth: 1

   modules/util.rst
   modules/matrix.rst
   modules/twiss.rst
   modules/normal.rst
   modules/convert.rst
   modules/invariant.rst
   modules/transport.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
